@@ -20,13 +20,13 @@ class NLLSP(NonLinProblem):
     def nllsp2nlp(self, solver, **solver_params):
 
         ff = lambda x: sum(asfarray(self.f(x))**2)
-        if self.userProvided.df:
-            dff = lambda x: dot(2*asfarray(self.f(x)), asfarray(self.df(x,useSparse=False)))
-            p = NLP.NLP(ff, self.x0, df=dff)
-        else:
-            p = NLP.NLP(ff, self.x0)
+        p = NLP.NLP(ff, self.x0)
         #p = NLP.NLP(FF, self.x0)
-        self.inspire(p, sameConstraints=True)
+        self.fill(p, sameConstraints=True)
+        if self.userProvided.df:
+            p.df = lambda x: dot(2*asfarray(self.f(x)), asfarray(self.df(x,useSparse=False)))
+        p.f = ff
+
 
 
         def nllsp_iterfcn(*args,  **kwargs):
